import { ICommandArguments, IHandlerParameters } from "../../cmd";
import { AbstractAuthHandler } from "../../imperative/src/auth/handlers/AbstractAuthHandler";
/**
 * Class to manage automatic storage of properties in team config.
 */
export declare class ConfigAutoStore {
    /**
     * Finds the profile where auto-store properties should be saved.
     * @param params CLI handler parameters object
     * @param profileProps List of properties required in the profile schema
     * @returns Tuple containing profile type and name, or undefined if no
     *          profile was found
     */
    static findActiveProfile(params: IHandlerParameters, profileProps: string[]): [string, string] | undefined;
    /**
     * Finds the token auth handler class for a team config profile.
     * @param profilePath JSON path of profile
     * @param cmdArguments CLI arguments which may specify a profile
     * @returns Auth handler class or undefined if none was found
     */
    static findAuthHandlerForProfile(profilePath: string, cmdArguments: ICommandArguments): AbstractAuthHandler | undefined;
    /**
     * Stores session config properties into a team config profile.
     * @param params CLI handler parameters object
     * @param sessCfg Session config containing properties to store
     * @param propsToStore Names of properties that should be stored
     */
    static storeSessCfgProps(params: IHandlerParameters, sessCfg: {
        [key: string]: any;
    }, propsToStore: string[]): Promise<void>;
    /**
     * Retrieves token value that will be auto-stored into session config.
     * @param params CLI handler parameters object
     * @param sessCfg Session config with credentials for basic or cert auth
     * @param profilePath JSON path of profile containing tokenType
     * @returns True if auth handler was found and token was fetched
     */
    private static fetchTokenForSessCfg;
}
