"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("../../../../../config");
const utilities_1 = require("../../../../../utilities");
/**
 * The get command group handler for cli configuration settings.
 */
class SchemaHandler {
    /**
     * Process the command and input.
     *
     * @param {IHandlerParameters} params Parameters supplied by yargs
     *
     * @throws {ImperativeError}
     */
    process(params) {
        return __awaiter(this, void 0, void 0, function* () {
            let profileConfigs;
            try {
                profileConfigs = utilities_1.ImperativeConfig.instance.loadedConfig.profiles;
            }
            catch (err) {
                params.response.console.error("Failed to load profile schemas");
                return;
            }
            const schema = config_1.ConfigSchema.buildSchema(profileConfigs);
            params.response.data.setObj(schema);
            params.response.console.log(JSON.stringify(schema, null, config_1.ConfigConstants.INDENT));
        });
    }
}
exports.default = SchemaHandler;
//# sourceMappingURL=schema.handler.js.map